@@ -1,5 +1,5 @@
 if (requireNamespace("testthat", quietly = TRUE)) {
-  library(testthat)
-  library(mlr3db)
+  library("testthat")
+  library("mlr3db")
   test_check("mlr3db")
 }
